@@ -1,5 +1,4 @@
-from . import parse_test, util_test, config_test
-
+from . import config_test, parse_test, util_test
 
 parse_test.test()
 util_test.test()
